pub struct Report<E>where
E: ReportableError,{ /* private fields */ }Expand description
A report with additional debugging info for an error.
A Report<E> can be used to identify exactly where the error E occurred in mediasan. The Debug
implementation will print a human-readable parser stack trace. The underlying error of type E can also be
retrieved e.g. for matching against with get_ref or into_inner.
Implementations
Sourceimpl<E> Report<E>where
E: ReportableError,
impl<E> Report<E>where
E: ReportableError,
Sourcepub fn into_inner(self) -> E
pub fn into_inner(self) -> E
Unwrap this report, returning the underlying error.